==> mathjinni_0.11.20101005-1.tar.gz: mathjinni-0.11.20101005/src/UnitConversion.h <==
#ifndef UNITCONVERSION_H
#define UNITCONVERSION_H

/*
  MathJinni - A simple formular calculator
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Number.h>
#include <Lum/Model/String.h>
#include <Lum/Model/Table.h>

#include "Configuration.h"
#include "Parser.h"

class UnitConversion : public Lum::Component, public ConfigPlugin
{
  Lum::Model::SizeTRef       type;
  Lum::Model::StringTableRef types;
  Lum::Model::SizeTRef       src;
  Lum::Model::StringTableRef srcUnits;
  Lum::Model::SizeTRef       dest;
  Lum::Model::StringTableRef destUnits;

  Lum::Model::StringRef      value;
  Lum::Model::StringRef      result;

  Parser                     parser;
  Parser::Variable           *variable;

private:
  void Convert();

public:
  UnitConversion();

  void CalcSize();

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

  void LoadData();
  void LoadConfig(Lum::Config::Node *top);
  void StoreConfig(Lum::Config::Node *top);
};

#endif

==> mathjinni_0.12.20101220-1.tar.gz: mathjinni-0.12.20101220/src/UnitConversion.h <==
#ifndef UNITCONVERSION_H
#define UNITCONVERSION_H

/*
  MathJinni - A simple formular calculator
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Number.h>
#include <Lum/Model/String.h>
#include <Lum/Model/Table.h>

#include "Configuration.h"
#include "Parser.h"

class UnitConversion : public Lum::Component, public ConfigPlugin
{
  Lum::Model::ULongRef       type;
  Lum::Model::StringTableRef types;
  Lum::Model::ULongRef       src;
  Lum::Model::StringTableRef srcUnits;
  Lum::Model::ULongRef       dest;
  Lum::Model::StringTableRef destUnits;

  Lum::Model::StringRef      value;
  Lum::Model::StringRef      result;

  Parser                     parser;
  Parser::Variable           *variable;

private:
  void Convert();

public:
  UnitConversion();

  void CalcSize();

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

  void LoadData();
  void LoadConfig(Lum::Config::Node *top);
  void StoreConfig(Lum::Config::Node *top);
};

#endif
